<!-- 
    Copyright (c) 2001, 2006 Rick Jelliffe and Academia Sinica Computing Center, Taiwan
-->

<!-- The command-line parameters are:
    phase           NMTOKEN | "#ALL" (default) Select the phase for validation
    allow-foreign   "true" | "false" (default)   Pass non-Schematron elements to the generated stylesheet
    diagnose= true | false|yes|no    Add the diagnostics to the assertion test in reports (yes|no are obsolete)
    generate-paths=true|false|yes|no   generate the @location attribute with XPaths (yes|no are obsolete)
    sch.exslt.imports semi-colon delimited string of filenames for some EXSLT implementations          
    optimize        "visit-no-attributes"     Use only when the schema has no attributes as the context nodes
    generate-fired-rule "true"(default) | "false"  Generate fired-rule elements
-->

<xsl:stylesheet
    version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
    xmlns:schold="http://www.ascc.net/xml/schematron"
    xmlns:iso="http://purl.oclc.org/dsdl/schematron"
    xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
    xmlns:tns="http://sbr.gov.au/comn/event.02.data"
    xmlns:i="http://www.w3.org/2001/XMLSchema-instance"
	
	xmlns:sbdm="http://sbr.gov.au/comn/sbdm.02.data"
	xmlns:isns="http://www.ato.gov.au/IS/2009/02"
	xmlns:cl="http://sbr.gov.au/comn/codelist.02.data"
	exclude-result-prefixes="schold cl"
	
	>

    <xsl:import href="iso_schematron_skeleton_for_saxon.xsl"/>

    <xsl:param name="diagnose">true</xsl:param>
    <xsl:param name="phase">
        <xsl:choose>
            <!-- Handle Schematron 1.5 and 1.6 phases -->
            <xsl:when test="//schold:schema/@defaultPhase">
                <xsl:value-of select="//schold:schema/@defaultPhase"/>
            </xsl:when>
            <!-- Handle ISO Schematron phases -->
            <xsl:when test="//iso:schema/@defaultPhase">
                <xsl:value-of select="//iso:schema/@defaultPhase"/>
            </xsl:when>
            <xsl:otherwise>#ALL</xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="allow-foreign">false</xsl:param>
    <xsl:param name="generate-paths">true</xsl:param>
    <xsl:param name="generate-fired-rule">true</xsl:param>
    <xsl:param name="optimize"/>
    <xsl:param name="output-encoding"/>
    <xsl:param name="sch.exslt.imports"/>



    <!-- Overrides skeleton.xsl -->
    <xsl:template name="process-root">
        <xsl:param name="title"/>
        <xsl:param name="contents" />
        <xsl:param name="queryBinding" >xslt1</xsl:param>
        <xsl:param name="schemaVersion" />
        <xsl:param name="id" />
        <xsl:param name="version"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />

        <axsl:variable name="results">
            <xsl:apply-templates mode="do-schema-p"/>
            <xsl:copy-of select="$contents"/>
        </axsl:variable>
        <axsl:if test="$results">
            <!--<tns:Event>
                <tns:MaximumSeverity.Code>
                    <axsl:choose>
                        <axsl:when test="$results//tns:Severity.Code[.='Error']">Error</axsl:when>
                        <axsl:when test="$results//tns:Severity.Code[.='Partial']">Partial</axsl:when>
                        <axsl:when test="$results//tns:Severity.Code[.='Warning']">Warning</axsl:when>
                        <axsl:when test="$results//tns:Severity.Code[.='Information']">Information</axsl:when>
                        <axsl:when test="$results//tns:Severity.Code[.='Progressive']">Progressive</axsl:when>
                        <axsl:otherwise>Information</axsl:otherwise>
                    </axsl:choose>
                </tns:MaximumSeverity.Code>
                <tns:EventItems>
                    <axsl:copy-of select="$results"/>
                </tns:EventItems>
            </tns:Event>-->
            <axsl:choose>
                <axsl:when test="$full-event='true'">
                    <sbdm:MessageEvent>
                        <sbdm:Message.Event.MaximumSeverity.Code>
                            <axsl:choose>
                                <axsl:when test="$results//sbdm:Message.Event.Item.Severity.Code[.='Error']">Error</axsl:when>
                                <axsl:when test="$results//sbdm:Message.Event.Item.Severity.Code[.='Warning']">Warning</axsl:when>
                                <axsl:otherwise>Information</axsl:otherwise>
                            </axsl:choose>
                        </sbdm:Message.Event.MaximumSeverity.Code>
                        <sbdm:MessageEventItems>
                            <axsl:copy-of select="$results"/>
                        </sbdm:MessageEventItems>
                    </sbdm:MessageEvent>
                </axsl:when>
                <axsl:otherwise>
                    <sbdm:MessageEventItems>
                        <axsl:copy-of select="$results"/>
                    </sbdm:MessageEventItems>
                </axsl:otherwise>
            </axsl:choose>
        </axsl:if>
    </xsl:template>

    <!-- Define the variables to be available at run-time. -->
    <xsl:template name="process-prolog">

        <axsl:import href="SMAT2201502Validator_Functions.xsl"/>
        <axsl:variable name="document-uri">
            <axsl:value-of select="document-uri(/)" />
        </axsl:variable>

        <!-- Variable to support the use of an apostrophe in country names. -->
        <xsl:text disable-output-escaping="yes">&lt;xsl:variable name="Apostrophe"&gt;&#39;&lt;/xsl:variable&gt;</xsl:text>

        <axsl:output method="xml" omit-xml-declaration="no" standalone="yes" indent="yes">
            <xsl:if test=" string-length($output-encoding) &gt; 0">
                <xsl:attribute name="encoding">
                    <xsl:value-of select=" $output-encoding"/>
                </xsl:attribute>
            </xsl:if>
        </axsl:output>
        <axsl:param name="full-event">false</axsl:param>
        <axsl:param name="document-sequence-number">1</axsl:param>
    </xsl:template>




    <xsl:template name="process-assert">
        <xsl:param name="test"/>
        <xsl:param name="diagnostics" />
        <xsl:param name="id" />
        <xsl:param name="flag" />
        <xsl:param name="properties" />

        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
        <xsl:choose>
            <!-- <xsl:when test="$diagnose = 'yes' or $diagnose= 'true' "> -->
            <xsl:when test="$diagnose">
                <xsl:call-template name="diagnosticsSplit">
                    <xsl:with-param name="str" select="$diagnostics"/>
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>



    </xsl:template>

    <xsl:template name="process-report">
        <xsl:param name="id"/>
        <xsl:param name="test"/>
        <xsl:param name="diagnostics"/>
        <xsl:param name="flag" />
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
        <xsl:if test="$diagnose = 'yes' or $diagnose='true' ">
            <!-- true/false is the new way -->
            <xsl:call-template name="diagnosticsSplit">
                <xsl:with-param name="str" select="$diagnostics"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="process-diagnostic">
        <xsl:param name="id"/>
        <!-- Rich parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />


        <sbdm:MessageEventItem>
            <sbdm:Message.Event.Item.Error.Code>
                <xsl:value-of select="tns:EventItem/tns:Error.Code/text()" />
            </sbdm:Message.Event.Item.Error.Code>

            <xsl:choose>
                <xsl:when test="string-length( tns:EventItem/tns:Severity.Code/text() ) &gt; 0">
                    <sbdm:Message.Event.Item.Severity.Code>
                        <xsl:value-of select="tns:EventItem/tns:Severity.Code/text()" />
                    </sbdm:Message.Event.Item.Severity.Code>
                </xsl:when>
                <xsl:otherwise>
                    <sbdm:Message.Event.Item.Severity.Code>Error</sbdm:Message.Event.Item.Severity.Code>
                </xsl:otherwise>
            </xsl:choose>

            <xsl:if test="string-length( tns:EventItem/tns:Short.Description/text() ) &gt; 0">
                <sbdm:Message.Event.Item.Short.Description>
                    <xsl:value-of select="tns:EventItem/tns:Short.Description/text()" />
                </sbdm:Message.Event.Item.Short.Description>
            </xsl:if>

            <xsl:if test="string-length( tns:EventItem/tns:Detailed.Description/text() ) &gt; 0">
                <sbdm:Message.Event.Item.Detailed.Description>
                    <xsl:value-of select="tns:EventItem/tns:Detailed.Description/text()" />
                </sbdm:Message.Event.Item.Detailed.Description>
            </xsl:if>


            <sbdm:Parameters>
                <xsl:for-each select="tns:EventItem/tns:Parameters/tns:Parameter">
                    <sbdm:Parameter>
                        <sbdm:Message.Event.Item.Parameter.Identifier>
                            <xsl:value-of select="tns:Parameter.Identifier/text()" />
                        </sbdm:Message.Event.Item.Parameter.Identifier>
                        <sbdm:Message.Event.Item.Parameter.Text>
                            <xsl:copy-of select ="tns:Parameter.Text/node()"/>
                        </sbdm:Message.Event.Item.Parameter.Text>
                    </sbdm:Parameter>
                </xsl:for-each>
                <sbdm:Parameter>
                    <sbdm:Message.Event.Item.Parameter.Identifier>RuleIdentifier</sbdm:Message.Event.Item.Parameter.Identifier>
                    <sbdm:Message.Event.Item.Parameter.Text>
                        <xsl:value-of select="substring($id, 2, string-length($id))" />
                        <!--<xsl:value-of select="$id" />-->
                    </sbdm:Message.Event.Item.Parameter.Text>
                </sbdm:Parameter>
            </sbdm:Parameters>


            <sbdm:Locations>
                <sbdm:Location>
                    <sbdm:BusinessDocument.Sequence.Number>
                        <axsl:value-of select="$document-sequence-number"/>
                    </sbdm:BusinessDocument.Sequence.Number>
                    <sbdm:Message.Event.Item.Location.Path.Text>
                        <axsl:apply-templates select="." mode="schematron-get-full-path-2"/>
                        <xsl:if test="string-length( sbdm:MessageEventItem/sbdm:Locations/sbdm:Location/sbdm:Message.Event.Item.Location.Path.Text ) &gt; 0">
                            <xsl:text disable-output-escaping="yes">&lt;xsl:text&gt;</xsl:text>/<xsl:value-of select="sbdm:MessageEventItem/sbdm:Locations/sbdm:Location/sbdm:Message.Event.Item.Location.Path.Text" /><xsl:text disable-output-escaping="yes">&lt;/xsl:text&gt;</xsl:text>
                        </xsl:if>
                    </sbdm:Message.Event.Item.Location.Path.Text>
                </sbdm:Location>
            </sbdm:Locations>

        </sbdm:MessageEventItem>

    </xsl:template>


    <!-- Overrides skeleton -->
    <xsl:template name="process-emph" >
        <xsl:param name="class" />
    </xsl:template>

    <xsl:template name="process-rule">
        <xsl:param name="id"/>
        <xsl:param name="context"/>
        <xsl:param name="flag"/>
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <xsl:template name="process-ns">
        <xsl:param name="prefix"/>
        <xsl:param name="uri"/>
    </xsl:template>

    <xsl:template name="process-p">
        <xsl:param name="icon"/>
        <xsl:param name="class"/>
        <xsl:param name="id"/>
        <xsl:param name="lang"/>
    </xsl:template>

    <xsl:template name="process-pattern">
        <xsl:param name="name"/>
        <xsl:param name="id"/>
        <xsl:param name="is-a"/>

        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <!-- Overrides skeleton -->
    <xsl:template name="process-message" >
        <xsl:param name="pattern"/>
        <xsl:param name="role"/>
    </xsl:template>


    <!-- Overrides skeleton -->
    <xsl:template name="process-span" >
        <xsl:param name="class" />
    </xsl:template>

</xsl:stylesheet>