<!-- 
	Copied from ISO_SVRL.xsl in order to create a very very simple html output.  Hoping to grab a better one
	if the ATO internet starts working again so i can find one...

	Derived from Conformance1-5.xsl.

	Copyright (c) 2001, 2006 Rick Jelliffe and Academia Sinica Computing Center, Taiwan
-->

<!-- The command-line parameters are:
	phase           NMTOKEN | "#ALL" (default) Select the phase for validation
	allow-foreign   "true" | "false" (default)   Pass non-Schematron elements to the generated stylesheet
	diagnose= true | false|yes|no    Add the diagnostics to the assertion test in reports (yes|no are obsolete)
	generate-paths=true|false|yes|no   generate the @location attribute with XPaths (yes|no are obsolete)
	sch.exslt.imports semi-colon delimited string of filenames for some EXSLT implementations          
	optimize        "visit-no-attributes"     Use only when the schema has no attributes as the context nodes
	generate-fired-rule "true"(default) | "false"  Generate fired-rule elements
-->

<xsl:stylesheet
	version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
	xmlns:iso="http://purl.oclc.org/dsdl/schematron"
	xmlns:isns="http://www.ato.gov.au/IS/2009/02"
	xmlns:i="http://www.w3.org/2001/XMLSchema-instance">

    <xsl:import href="iso_schematron_skeleton_for_saxon.xsl"/>

    <xsl:param name="diagnose" >true</xsl:param>
    <xsl:param name="phase" >
        <xsl:choose>
            <!-- Handle ISO Schematron phases -->
            <xsl:when test="//iso:schema/@defaultPhase">
                <xsl:value-of select="//iso:schema/@defaultPhase"/>
            </xsl:when>
            <xsl:otherwise>#ALL</xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="allow-foreign" >false</xsl:param>
    <xsl:param name="generate-paths" >true</xsl:param>
    <xsl:param name="generate-fired-rule" >true</xsl:param>
    <xsl:param name="optimize"/>

    <xsl:param name="output-encoding" ></xsl:param>

    <!-- e.g. saxon file.xml file.xsl "sch.exslt.imports=.../string.xsl;.../math.xsl" -->
    <xsl:param name="sch.exslt.imports" />

    <!-- ================================================================ -->

    <xsl:template name="process-prolog">

        <axsl:import href="SMAT2201502Validator_Functions.xsl"/>
        <axsl:variable name="document-uri">
            <axsl:value-of select="document-uri(/)" />
        </axsl:variable>

        <!-- Variable to support the use of an apostrophe in country names. -->
        <xsl:text disable-output-escaping="yes">&lt;xsl:variable name="Apostrophe"&gt;&#39;&lt;/xsl:variable&gt;</xsl:text>


        <axsl:output method="xml" omit-xml-declaration="no" standalone="yes"
                indent="no">
            <xsl:if test=" string-length($output-encoding) &gt; 0">
                <xsl:attribute name="encoding">
                    <xsl:value-of select=" $output-encoding" />
                </xsl:attribute>
            </xsl:if>
        </axsl:output>

    </xsl:template>

    <!-- Overrides skeleton.xsl -->
    <xsl:template name="process-root">
        <xsl:param name="title"/>
        <xsl:param name="contents" />
        <xsl:param name="queryBinding" >xslt1</xsl:param>
        <xsl:param name="schemaVersion" />
        <xsl:param name="id" />
        <xsl:param name="version"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />

        <ProcessMessages xmlns="http://www.ato.gov.au/IS/2009/02">
            <xsl:apply-templates mode="do-schema-p" />
            <xsl:copy-of select="$contents" />
        </ProcessMessages>

    </xsl:template>

    <xsl:template name="process-assert">
        <xsl:param name="test"/>
        <xsl:param name="diagnostics" />
        <xsl:param name="id" />
        <xsl:param name="flag" />
        <xsl:param name="properties" />

        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />

        <xsl:choose>
            <xsl:when test="$diagnose">
                <xsl:call-template name="diagnosticsSplit">
                    <xsl:with-param name="str" select="$diagnostics"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <ProcessMessage xmlns="http://www.ato.gov.au/IS/2009/02">
                    <CategoryCode>Syntax</CategoryCode>
                    <xsl:if test="string-length( $id ) &gt; 0">
                        <Code>
                            <xsl:value-of select="$id" />
                        </Code>
                    </xsl:if>
                    <Description>
                        <xsl:apply-templates mode="text" />
                    </Description>
                    <xsl:if test="$generate-paths = 'true' or $generate-paths= 'yes'">
                        <Location>
                            <axsl:apply-templates select="." mode="schematron-get-full-path-2"/>
                            <xsl:if test="string-length( $subject ) &gt; 0">
                                <xsl:text disable-output-escaping="yes">&lt;xsl:text&gt;</xsl:text>/<xsl:value-of select="$subject" /><xsl:text disable-output-escaping="yes">&lt;/xsl:text&gt;</xsl:text>
                            </xsl:if>
                        </Location>
                    </xsl:if>
                    <LongDescription i:nil="true" />
                    <PropertyName i:nil="true" />
                    <Severity>Error</Severity>
                </ProcessMessage>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="process-report">
        <xsl:param name="id"/>
        <xsl:param name="test"/>
        <xsl:param name="diagnostics"/>
        <xsl:param name="flag" />
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />

    </xsl:template>

    <xsl:template name="process-diagnostic">
        <xsl:param name="id"/>
        <!-- Rich parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
        <ProcessMessage xmlns="http://www.ato.gov.au/IS/2009/02">
            <CategoryCode>Syntax</CategoryCode>
            <isns:Code>
                <xsl:value-of select="isns:ProcessMessage/isns:Code/text()" />
            </isns:Code>
            <xsl:if test="string-length( isns:ProcessMessage/isns:Description/text() ) &gt; 0">
                <isns:Description>
                    <xsl:value-of select="isns:ProcessMessage/isns:Description/text()" />
                </isns:Description>
            </xsl:if>
            <xsl:if test="$generate-paths = 'true' or $generate-paths= 'yes'">
                <Location>
                    <axsl:apply-templates select="." mode="schematron-get-full-path-2"/>
                    <xsl:if test="string-length( isns:ProcessMessage/isns:Location[1] ) &gt; 0">
                        <xsl:text disable-output-escaping="yes">&lt;xsl:text&gt;</xsl:text>/<xsl:value-of select="isns:ProcessMessage/isns:Location" /><xsl:text disable-output-escaping="yes">&lt;/xsl:text&gt;</xsl:text>
                    </xsl:if>
                </Location>
            </xsl:if>
            <xsl:if test="string-length( isns:ProcessMessage/isns:LongDescription/text() ) &gt; 0">
                <isns:LongDescription>
                    <xsl:value-of select="isns:ProcessMessage/isns:LongDescription/text()" />
                </isns:LongDescription>
            </xsl:if>
            <xsl:if test="count(isns:ProcessMessage/isns:Parameters) = 1">
                <isns:Parameters>
                    <!--<xsl:apply-templates select="isns:ProcessMessage/isns:Parameters/isns:Parameter" mode="text">
          </xsl:apply-templates>-->

                    <xsl:for-each select="isns:ProcessMessage/isns:Parameters/isns:Parameter">
                        <isns:Parameter>
                            <isns:Name>
                                <xsl:value-of select="isns:Name/text()" />
                            </isns:Name>
                            <isns:Value>
                                <xsl:copy-of select ="isns:Value/node()"/>
                            </isns:Value>
                        </isns:Parameter>
                    </xsl:for-each>
                </isns:Parameters>
            </xsl:if>
            <PropertyName i:nil="true" />
            <xsl:choose>
                <xsl:when test="string-length( isns:ProcessMessage/isns:Severity/text() ) &gt; 0">
                    <isns:Severity>
                        <xsl:value-of select="isns:ProcessMessage/isns:Severity/text()" />
                    </isns:Severity>
                </xsl:when>
                <xsl:otherwise>
                    <Severity>Error</Severity>
                </xsl:otherwise>
            </xsl:choose>
        </ProcessMessage>
    </xsl:template>


    <!-- Overrides skeleton -->
    <xsl:template name="process-emph" >
        <xsl:param name="class" />

    </xsl:template>

    <xsl:template name="process-rule">
        <xsl:param name="id"/>
        <xsl:param name="context"/>
        <xsl:param name="flag"/>
        <xsl:param name="properties" />
        <!-- "Linkable" parameters -->
        <xsl:param name="role"/>
        <xsl:param name="subject"/>
        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />

    </xsl:template>

    <xsl:template name="process-ns">
        <xsl:param name="prefix"/>
        <xsl:param name="uri"/>
    </xsl:template>

    <xsl:template name="process-p">
        <xsl:param name="icon"/>
        <xsl:param name="class"/>
        <xsl:param name="id"/>
        <xsl:param name="lang"/>

    </xsl:template>

    <xsl:template name="process-pattern">
        <xsl:param name="name"/>
        <xsl:param name="id"/>
        <xsl:param name="is-a"/>

        <!-- "Rich" parameters -->
        <xsl:param name="fpi" />
        <xsl:param name="icon" />
        <xsl:param name="lang" />
        <xsl:param name="see" />
        <xsl:param name="space" />
    </xsl:template>

    <!-- Overrides skeleton -->
    <xsl:template name="process-message" >
        <xsl:param name="pattern"/>
        <xsl:param name="role"/>
    </xsl:template>


    <!-- Overrides skeleton -->
    <xsl:template name="process-span" >
        <xsl:param name="class" />
    </xsl:template>

</xsl:stylesheet>